@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 2585 2009-11-21 05:16:40Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 2595 2009-11-24 01:44:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -132,7 +132,9 @@ class BaseFrameContainer extends Core
 							$cmd != M3_REQUEST_CMD_SHOW_POSITION &&				// 表示位置を表示するとき
 							$cmd != M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET &&	// 表示位置を表示するとき(ウィジェット付き)
 							$cmd != M3_REQUEST_CMD_FIND_WIDGET &&				// ウィジェットを検索
-							$cmd != M3_REQUEST_CMD_DO_WIDGET){					// ウィジェット単体実行
+							$cmd != M3_REQUEST_CMD_DO_WIDGET &&					// ウィジェット単体実行
+							$cmd != M3_REQUEST_CMD_PREVIEW){					// サイトのプレビューを表示
+							
 							// 標準のアクセスでは、上記コマンド以外は受け付けない
 							$canAccess = false;
 							$isErrorAccess = true;		// 不正アクセス
@@ -148,7 +150,9 @@ class BaseFrameContainer extends Core
 							$cmd != M3_REQUEST_CMD_SHOW_POSITION &&				// 表示位置を表示するとき
 							$cmd != M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET &&	// 表示位置を表示するとき(ウィジェット付き)
 							$cmd != M3_REQUEST_CMD_FIND_WIDGET &&				// ウィジェットを検索
-							$cmd != M3_REQUEST_CMD_DO_WIDGET){					// ウィジェット単体実行
+							$cmd != M3_REQUEST_CMD_DO_WIDGET &&					// ウィジェット単体実行
+							$cmd != M3_REQUEST_CMD_PREVIEW){					// サイトのプレビューを表示
+							
 							$isErrorAccess = true;		// 不正アクセス
 						}
 					}
