@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.9.x SVN: $Id: global.php 2586 2009-11-21 05:34:19Z fishbone $
+ * @version    Release 1.9.x SVN: $Id: global.php 2597 2009-11-26 02:03:59Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -43,8 +43,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.9.15');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2009/11/19');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.9.17');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2009/11/24');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -152,6 +152,7 @@ define('M3_REQUEST_PARAM_ADMIN_KEY',				'adminkey');		// 管理者一時キー
 define('M3_REQUEST_PARAM_OPEN_BY',					'openby');			// ウィンドウの開き方
 define('M3_REQUEST_PARAM_SHOW_HEADER',				'head');			// ヘッダ部表示制御
 define('M3_REQUEST_PARAM_SHOW_FOOTER',				'foot');			// フッタ部表示制御
+define('M3_REQUEST_PARAM_SHOW_MENU',				'menu');			// メニュー部表示制御
 define('M3_REQUEST_PARAM_DEF_PAGE_ID',      		'_page');			// ページID(画面編集用)
 define('M3_REQUEST_PARAM_DEF_PAGE_SUB_ID',      	'_sub');			// ページサブID(画面編集用)
 define('M3_REQUEST_PARAM_PAGE_DEF_SERIAL',			'_defserial');		// ページ定義のレコードシリアル番号(設定画面起動時)
@@ -179,7 +180,6 @@ define('M3_REQUEST_CMD_SHOW_WIDGET',      			'showwidget');			// ウィジェッ
 define('M3_REQUEST_CMD_DO_WIDGET',      			'dowidget');			// ウィジェット単体オペレーション
 define('M3_REQUEST_CMD_CONFIG_WIDGET',      		'configwidget');		// ウィジェットの設定
 define('M3_REQUEST_CMD_PREVIEW',      				'preview');				// サイトのプレビューを表示
-//define('M3_REQUEST_CMD_GO_LOGIN',      				'gologin');				// ログイン画面を表示
 define('M3_REQUEST_CMD_LOGIN',      				'login');				// ログイン
 define('M3_REQUEST_CMD_LOGOUT',      				'logout');				// ログアウト
 define('M3_REQUEST_CMD_CHANGE_TEMPLATE',			'changetemplate');		// テンプレートの変更
