@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 2524 2009-11-06 06:42:05Z fishbone $
+ * @version    SVN: $Id: envManager.php 2579 2009-11-20 10:24:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -1404,6 +1404,15 @@ class EnvManager extends Core
 	{
 		return $this->defaultPageSubId;
 	}
+	/**
+	 * 管理画面のデフォルトのページサブID
+	 *
+	 * @return string 		デフォルトのページサブID
+	 */
+	public function getAdminDefaultPageSubId()
+	{
+		return $this->getDefaultPageSubIdByPageId(self::DEFAULT_ADMIN_PAGE_ID);
+	}
 	/**
 	 * 指定ページのデフォルトのページサブID
 	 *
