@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
+ * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 2596 2009-11-26 02:02:44Z fishbone $
  * @link       http://www.magic3.org
  */
 //require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -78,6 +78,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$marginRight = $request->trimValueOf('item_right');			// 右マージン
 		$title = $request->trimValueOf('item_title');			// タイトル名
 		$titleVisible = ($request->trimValueOf('item_title_visible') == 'on') ? 1 : 0;		// タイトルを表示するかどうか
+		$widgetId = $request->trimValueOf('widget_id');			// ウィジェットID
 		$act = $request->trimValueOf('act');
 		
 		$replaceNew = false;		// データを再取得するかどうか
@@ -87,6 +88,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$this->checkNumeric($marginBottom, 'マージン(下)', true);
 			$this->checkNumeric($marginLeft, 'マージン(左)', true);
 			$this->checkNumeric($marginRight, 'マージン(右)', true);
+			$this->checkInput($widgetId, 'ウィジェットID');
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
@@ -102,6 +104,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					$replaceNew = true;			// データを再取得
+					
+					// キャッシュをクリア
+					$this->gCache->clearCacheByWidgetConfigId($widgetId, $defConfigId);
+		
+					// 親ウィンドウを更新
+					$this->gPage->updateParentWindow($defSerial);
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
@@ -115,6 +123,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$marginRight = '';			// 右マージン
 			$title = '';			// タイトル名
 			$titleVisible = 1;		// タイトルを表示するかどうか
+			$widgetId = '';	// ウィジェットID
 			$replaceNew = true;
 		}
 		// 表示データ再取得
@@ -149,6 +158,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				}
 				$title = $row['pd_title'];			// タイトル名
 				$titleVisible = $row['pd_title_visible'];			// タイトルを表示するかどうか
+				$widgetId = $row['pd_widget_id'];	// ウィジェットID
 			}
 		}
 		
@@ -161,6 +171,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "right", $marginRight);			// 右マージン
 		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));				// タイトル名
 		if (!empty($titleVisible)) $this->tmpl->addVar("_widget", "title_visible", 'checked');		// タイトルを表示するかどうか
+		$this->tmpl->addVar("_widget", "widget_id", $widgetId);				// ウィジェットID
 		
 		// ページ定義IDとページ定義のレコードシリアル番号を更新
 		$this->endPageDefParam($defSerial, $defConfigId, $this->paramObj);
