@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 2510 2009-11-03 05:12:07Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 2596 2009-11-26 02:02:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -959,8 +959,8 @@ class admin_mainDb extends BaseDb
 	 */
 	function getPageDef($serialNo, &$row)
 	{
-		$queryStr  = 'select * from _page_def ';
-		$queryStr .=   'where pd_serial = ?';
+		$queryStr  = 'SELECT * FROM _page_def LEFT JOIN _widgets on pd_widget_id = wd_id AND wd_deleted = false ';
+		$queryStr .=   'WHERE pd_serial = ?';
 		return $this->selectRecord($queryStr, array($serialNo), $row);
 	}
 	/**
